@@ -14,7 +14,7 @@ class NotFalseBoolean(Base):
         setattr(instance, self.name, value)
 
     def __set_name__(self, owner, name):
-        self.name = name
+        self.name = f'_{name.lower()}'
 
 
 class NotTrueBoolean(Base):
@@ -30,4 +30,4 @@ class NotTrueBoolean(Base):
         setattr(instance, self.name, value)
 
     def __set_name__(self, owner, name):
-        self.name = name
+        self.name = f'_{name.lower()}'
